@@ -1,7 +1,7 @@
 package Perinci::Sub::Complete;
 
-our $DATE = '2015-03-01'; # DATE
-our $VERSION = '0.72'; # VERSION
+our $DATE = '2015-03-03'; # DATE
+our $VERSION = '0.73'; # VERSION
 
 use 5.010001;
 use strict;
@@ -94,7 +94,7 @@ sub complete_from_schema {
     my %args = @_;
     my $sch  = $args{schema}; # must be normalized
     my $word = $args{word} // "";
-    my $ci   = $args{ci};
+    my $ci   = $args{ci} // $Complete::OPT_CI;
 
     my $fres;
     $log->tracef("[comp][periscomp] entering complete_from_schema, word=<%s>, schema=%s", $word, $sch);
@@ -272,7 +272,7 @@ _
         },
         ci => {
             summary => 'Whether to be case-insensitive',
-            schema => ['bool*', default => 0],
+            schema => ['bool*'],
         },
         args => {
             summary => 'Collected arguments so far, '.
@@ -314,7 +314,7 @@ sub complete_arg_val {
         $log->tracef("[comp][periscomp] arg is not supplied, declining");
         goto RETURN_RES;
     };
-    my $ci   = $args{ci} // 0;
+    my $ci   = $args{ci} // $Complete::OPT_CI;
     my $word = $args{word} // '';
 
     # XXX reject if meta's v is not 1.1
@@ -445,7 +445,7 @@ sub complete_arg_elem {
         $log->tracef("[comp][periscomp] index is not supplied, declining");
         goto RETURN_RES;
     };
-    my $ci   = $args{ci} // 0;
+    my $ci   = $args{ci} // $Complete::OPT_CI;
     my $word = $args{word} // '';
 
     # XXX reject if meta's v is not 1.1
@@ -717,7 +717,7 @@ sub complete_cli_arg {
         my $type  = $cargs{type};
         my $ospec = $cargs{ospec} // '';
         my $word  = $cargs{word};
-        my $ci    = $cargs{ci};
+        my $ci    = $cargs{ci} // $Complete::OPT_CI;
 
         my $fres;
 
@@ -901,7 +901,7 @@ Perinci::Sub::Complete - Complete command-line argument using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.72 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-03-01.
+This document describes version 0.73 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-03-03.
 
 =head1 SYNOPSIS
 
@@ -959,7 +959,7 @@ Argument name.
 
 Collected arguments so far, will be passed to completion routines.
 
-=item * B<ci> => I<bool> (default: 0)
+=item * B<ci> => I<bool>
 
 Whether to be case-insensitive.
 
@@ -1060,7 +1060,7 @@ Argument name.
 
 Collected arguments so far, will be passed to completion routines.
 
-=item * B<ci> => I<bool> (default: 0)
+=item * B<ci> => I<bool>
 
 Whether to be case-insensitive.
 
@@ -1281,7 +1281,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Complete>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Complete>.
 
 =head1 BUGS
 
